#include <iostream>
#include <iomanip>
#include <stdexcept>
#include <limits>
#include <stdlib.h>

using namespace std;

int bezpecny_soucet(int a, int b)
{
	if ((a > 0) && (b > numeric_limits<int>::max() - a))
	{
		throw overflow_error("Vsledek stn > INT_MAX");
	}
	if ((a < 0) && (b < numeric_limits<int>::min() + a))
	{
		throw overflow_error("Vsledek stn < INT_MIN");
	}
	return a + b;
}

int bezpecny_rozdil(int a, int b)
{
	if ((b < 0) && (a > numeric_limits<int>::max() + b))
	{
		throw overflow_error("Vsledek odetn > INT_MAX");
	}
	if ((b > 0) && (a < numeric_limits<int>::min() + b))
	{
		throw overflow_error("Vsledek odetn < INT_MIN");
	}
	return a - b;
}

int bezpecny_soucin(int a, int b)
{
	if (b == 0)
	{
		return 0;
	}
	if (a > numeric_limits<int>::max() / b)
	{
		throw overflow_error("Vsledek nsoben > INT_MAX");
	}
	if (a < numeric_limits<int>::min() / b)
	{
		throw overflow_error("Vsledek < INT_MIN");
	}
	return a * b;
}

int bezpecny_podil(int a, int b)
{
	if (b == 0)
	{
		throw domain_error("Dlen nulou");
	}
	if ((a == numeric_limits<int>::min()) && (b == -1))
	{
		throw overflow_error("Vsledek dlen mimo rozsah");
	}
	return a / b;
}


int max = numeric_limits<int>::max();
int min = numeric_limits<int>::min();

void bezpecny_vypis(int a, int b, int(*operace)(int, int))
{
	try
	{
		cout << operace(a, b) << endl;
	}
	catch (const std::exception& e)
	{
		cout << e.what() << endl;
	}
}

int faktorial(int n)
{
	if (n < 0)
	{
		throw invalid_argument("Zporn parametr faktorilu");
	}
	int vysledek = 1;
	while (n > 1)
	{
		vysledek = bezpecny_soucin(n, vysledek);
		n--;
	}
	return vysledek;
}

void vypis(int od, int po)
{
	for (int i = od; i < po + 1; i++)
	{
		try {
			cout << setw(3) << i << ": ";
			cout << setw(11) << faktorial(i);
			cout << ";" << endl;
		}
		catch (exception &e)
		{
			cout << e.what() << endl;
		}
	}
}


int main()
{
	system("CHCP 1250 > NUL");
	vypis(-1, 13);
}
