#include <locale>
#include <stdexcept>
#include <stdlib.h>
#include "volba.h"
#include "znaky.h"
#include "komparatory.h"
#include "inicializace.h"

string volba::zalozni_text_napovedy = retezec_Cp1250_na_string_Cp852(R"(
SORT - program pro seazen dek danho souboru. Pouit:
sort volba < vstupn-soubor > vstupn-soubor
Mon volby:
-n nebo /n     azen podle sel na potcch dek
-l nebo /l     lexikografick azen
-a nebo /a     abecedn azen

Tyto volby uruj vzestupn azen. Pro sestupn azen
pipojte za volbu znak o (nap. -lo zpsob sestupn
lexikografick azen).

(C) Pikvorky software 2017
)");

size_t volba::pocet_voleb = 0;

map< string, pair<volba::u_komparator, bool>> volba::tabulka_voleb{
	{ "-l", {new lexikograficky_komparator, false} },
	{ "-n", {new numericky_komparator, false} },
	{ "-a", {new abecedni_komparator, false} },
	{ "-lo",{ new lexikograficky_komparator, true } },
	{ "-no",{ new numericky_komparator, true } },
	{ "-ao",{ new abecedni_komparator, true } },
};

volba::volba(int argc, char ** argv)
{
	try
	{
		pocet_voleb++;
		if (argc != 2)
		{
			throw runtime_error("patn poet parametr");
		}
		if (argv[1][0] == '/')
		{
			argv[1][0] = '-';
		}
		zadana_volba = tabulka_voleb.at(argv[1]);
	}
	catch (exception &e)
	{
		nacti_napovedu();
		napoveda();
	}
}

void volba::nacti_napovedu()
{
	try
	{
		string text_pom;
		inicializator.nacti_text("[npovda]", text_pom);
		text_napovedy = string_Cp1250_na_string_Cp852(text_pom);
	}
	catch (runtime_error e)
	{
		text_napovedy = zalozni_text_napovedy;
	}
}

void volba::napoveda()
{

	cerr << text_napovedy << endl;
	exit(1);
}

pair<volba::u_komparator, bool> volba::zvoleno()
{
	return zadana_volba;
}

void volba::uvolni_komparatory()
{
	for (auto pom : tabulka_voleb)
	{
		delete pom.second.first;
	}	
}


